using System;
using System.Runtime.InteropServices;

/// <summary>
/// PVG-16B API library definitions
/// </summary>
public class PVG16B
{
    //
    // Return Value
    //
    public const int PVG16B_OK = 0;
    public const int PVG16B_INVALID_ID = 1;
    public const int PVG16B_DEVICE_NOT_FOUND = 2;
    public const int PVG16B_DEVICE_NOT_OPENED = 3;
    public const int PVG16B_OTHER_ERROR = 4;
    public const int PVG16B_COMMUNICATION_ERROR = 5;
    public const int PVG16B_INVALID_PARAMETER = 6;
    public const int PVG16B_EXECUTION_ERROR = 7;
    public const int PVG16B_MEMORY_ERROR = 8;

    //
    // Constants
    //

    // Output mode
    public const byte PVG16B_OUTPUT_MODE_DIRECT = 0;				// Direct mode (direct output)
    public const byte PVG16B_OUTPUT_MODE_PC_START = 1;				// Program mode (use step memory)
    public const byte PVG16B_OUTPUT_MODE_TRIGGER_START_RISING = 2;	// Program mode (use step memory)
    public const byte PVG16B_OUTPUT_MODE_TRIGGER_START_FALLING = 3;	// Program mode (use step memory)
    public const byte PVG16B_OUTPUT_MODE_STEP_TRIGGER_RISING = 4;	// Program mode (use step memory)
    public const byte PVG16B_OUTPUT_MODE_STEP_TRIGGER_FALLING = 5;	// Program mode (use step memory)

    // Status (for Program mode)
    public const byte PVG16B_STATUS_NODATA = 0;
    public const byte PVG16B_STATUS_READY = 1;
    public const byte PVG16B_STATUS_WAITING = 2;
    public const byte PVG16B_STATUS_RUNNING = 3;

    //
    // Device Functions
    //
    [DllImport("PVG16B.dll")]
    public static extern int PVG16B_GetNumberOfDevices (out int Number);
    [DllImport("PVG16B.dll")]
    public static extern int PVG16B_GetSerialNumber (int Index, out int SerialNumber);
    [DllImport("PVG16B.dll")]
    public static extern int PVG16B_Open (out byte ID);
    [DllImport("PVG16B.dll")]
    public static extern int PVG16B_OpenBySerialNumber (int SerialNumber, out byte ID);
    [DllImport("PVG16B.dll")]
    public static extern int PVG16B_Close(byte ID);

    //
    // D/A Control Functions
    //
    [DllImport("PVG16B.dll")]
    public static extern int PVG16B_GetStatus(byte ID, out byte Status, out byte ExtState);
    [DllImport("PVG16B.dll")]
    public static extern int PVG16B_GetOutputMode(byte ID, out byte Mode);
    [DllImport("PVG16B.dll")]
    public static extern int PVG16B_SetOutputMode(byte ID, byte Mode);
    [DllImport("PVG16B.dll")]
    public static extern int PVG16B_DirectOutput(byte ID, double Voltage);
    [DllImport("PVG16B.dll")]
    public static extern int PVG16B_GetStepTime(byte ID, out int Time);
    [DllImport("PVG16B.dll")]
    public static extern int PVG16B_SetStepTime(byte ID, int Time);
    [DllImport("PVG16B.dll")]
    public static extern int PVG16B_GetStepCount(byte ID, out int Count);
    [DllImport("PVG16B.dll")]
    public static extern int PVG16B_WriteStepMemory (byte ID, [MarshalAs(UnmanagedType.AsAny), InAttribute(), OutAttribute()] object Data, int Count);
    [DllImport("PVG16B.dll")]
    public static extern int PVG16B_ReadStepCounter(byte ID, out int Counter);
    [DllImport("PVG16B.dll")]
    public static extern int PVG16B_Start (byte ID);
    [DllImport("PVG16B.dll")]
    public static extern int PVG16B_Cancel(byte ID);
}
