/*++

Copyright (c) 2024 ELMOS Co., Ltd.

Module Name:
	PVG16B.h
Abstract:
	PVG16B API library definitions
Revision History:
	24/03/06	Created.

--*/

#ifndef PVG16B_H
#define PVG16B_H

#ifdef PVG16B_EXPORTS_
#define PVG16B_API __declspec(dllexport)
#else
#define PVG16B_API __declspec(dllimport)
#endif

//
// Return Value
//
enum {
    PVG16B_OK,
    PVG16B_INVALID_ID,
    PVG16B_DEVICE_NOT_FOUND,
    PVG16B_DEVICE_NOT_OPENED,
	PVG16B_OTHER_ERROR,
	PVG16B_COMMUNICATION_ERROR,
	PVG16B_INVALID_PARAMETER,
	PVG16B_EXECUTION_ERROR,
	PVG16B_MEMORY_ERROR
};

//
// Constants
//

// Output mode
#define	PVG16B_OUTPUT_MODE_DIRECT					0	// Direct mode (direct output)
#define	PVG16B_OUTPUT_MODE_PC_START					1	// Program mode (use step memory)
#define	PVG16B_OUTPUT_MODE_TRIGGER_START_RISING		2	// Program mode (use step memory)
#define	PVG16B_OUTPUT_MODE_TRIGGER_START_FALLING	3	// Program mode (use step memory)
#define	PVG16B_OUTPUT_MODE_STEP_TRIGGER_RISING		4	// Program mode (use step memory)
#define	PVG16B_OUTPUT_MODE_STEP_TRIGGER_FALLING		5	// Program mode (use step memory)

// Status (for Program mode)
#define	PVG16B_STATUS_NODATA	0
#define	PVG16B_STATUS_READY		1
#define	PVG16B_STATUS_WAITING	2
#define	PVG16B_STATUS_RUNNING	3

#ifdef __cplusplus
extern "C" {
#endif

//
// Function definitions
//
PVG16B_API int WINAPI PVG16B_GetNumberOfDevices (int *Number);
PVG16B_API int WINAPI PVG16B_GetSerialNumber (int Index, int *SerialNumber);
PVG16B_API int WINAPI PVG16B_Open (BYTE *ID);
PVG16B_API int WINAPI PVG16B_OpenBySerialNumber (int SerialNumber, BYTE *ID);
PVG16B_API int WINAPI PVG16B_Close (BYTE ID);

PVG16B_API int WINAPI PVG16B_GetStatus (BYTE ID, BYTE *Status, BYTE *ExtState);
PVG16B_API int WINAPI PVG16B_GetOutputMode (BYTE ID, BYTE *Mode);
PVG16B_API int WINAPI PVG16B_SetOutputMode (BYTE ID, BYTE Mode);
PVG16B_API int WINAPI PVG16B_DirectOutput (BYTE ID, double Voltage);
PVG16B_API int WINAPI PVG16B_GetStepTime (BYTE ID, int *Time);
PVG16B_API int WINAPI PVG16B_SetStepTime (BYTE ID, int Time);
PVG16B_API int WINAPI PVG16B_GetStepCount (BYTE ID, int *Count);
PVG16B_API int WINAPI PVG16B_WriteStepMemory (BYTE ID, double *Data, int Count);
PVG16B_API int WINAPI PVG16B_ReadStepCounter (BYTE ID, int *Counter);
PVG16B_API int WINAPI PVG16B_Start (BYTE ID);
PVG16B_API int WINAPI PVG16B_Cancel (BYTE ID);

#ifdef __cplusplus
}
#endif

#endif  /* PVG16B_H */
